@@ -93,7 +93,6 @@ QScriptValue constructQRectFClass(QScriptEngine *engine);
 QScriptValue constructQSizeFClass(QScriptEngine *engine);
 QScriptValue constructQSizePolicyClass(QScriptEngine *engine);
 QScriptValue constructTimerClass(QScriptEngine *engine);
-void registerNonGuiMetaTypes(QScriptEngine *engine);
 void registerSimpleAppletMetaTypes(QScriptEngine *engine);
 
 KSharedPtr<UiLoader> SimpleJavaScriptApplet::s_widgetLoader;
@@ -581,7 +580,6 @@ void SimpleJavaScriptApplet::setupObjects()
     global.setProperty("FrameSvg", m_engine->newFunction(SimpleJavaScriptApplet::newPlasmaFrameSvg));
     global.setProperty("ExtenderItem", m_engine->newFunction(SimpleJavaScriptApplet::newPlasmaExtenderItem));
 
-    registerNonGuiMetaTypes(m_engine);
     registerSimpleAppletMetaTypes(m_engine);
     installWidgets(m_engine);
 }
